@@ -99,7 +99,7 @@ class Qubits(Hilbert):
         return Qubits.__symbolic == True
 
     def setPsi(self, psi):
-        if (not Qubits.__symbolic):
+        if (Qubits.__symbolic):
             Qubits.__psi = sp.Matrix(psi)
         else:
             Qubits.__psi = cp.array(psi)
@@ -107,10 +107,10 @@ class Qubits(Hilbert):
     def getPsi(self):
         return Qubits.__psi
 
-    def getDicPsi(self):#value = Utils.texfix(Qubits.__psi, self.__q_number, Qubits.first_left)
+    def getDictPsi(self):
         size_p = self.__q_number
         size = 2 ** size_p
-        labels = ["|" + "{0:b}".format(i).zfill(size_p) + ">" for i in range(size)]
+        labels = ["{0:b}".format(i).zfill(size_p) for i in range(size)]
         if (self.__symbolic):
             value_l = [Utils.textSymbolfix(str(value), self.__q_number, Qubits.first_left) for value in Qubits.__psi]
             dictPsi = {label: value_l[i] for i, label in enumerate(labels)}
